pub trait ToFormattedStr: Sealed + Sized { }Expand description
Marker trait for number types that can be formatted without heap allocation (see Buffer).
This trait is sealed; so you may not implement it on your own types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".